@@ -235,6 +235,27 @@ def dataset_uploadBag(file_path, source):
     except Exception as e:
         click.echo(f"An error occurred: {e}")
 
+def upload_bag(rosbag_file_name, source):
+    with open(rosbag_file_name, 'rb') as f:
+        files = {'file': f}
+        response = requests.post(f"{base_url}/datasets/uploadBag", files=files)
+        if response.status_code == 200:
+            response_data = response.json()
+            click.echo(f"Message: {response_data['message']}.")
+
+            for inserted in response_data['inserted_objects']:
+                response = requests.put(
+                    f"{base_url}/datasets/{inserted[1]}", 
+                    json={"Source": source}
+                )
+                if response.status_code == 200:
+                    click.echo("Dataset updated successfully")
+                    
+        elif response.status_code == 400:
+            click.echo(f"Error: {response.json()['error']}")
+        else:
+            click.echo(f"Failed to upload the file. Status code: {response.status_code}")
+
 @cli.command()
 @click.argument('topics_file', type=click.Path(exists=True))
 @click.argument('rosbag_file_name')
@@ -262,9 +283,28 @@ def record_rosbag(topics_file, rosbag_file_name, source, delete_rosbag):
         print("Stopping rosbag recording")
         process.terminate()
         print("Recording stopped")
+
         # send rosbag file through api
-        dataset_uploadBag(rosbag_file_name, source)
-        # Add to here
+        with open(rosbag_file_name, 'rb') as f:
+            files = {'file': f}
+            response = requests.post(f"{base_url}/datasets/uploadBag", files=files)
+            if response.status_code == 200:
+                response_data = response.json()
+                click.echo(f"Message: {response_data['message']}.")
+
+                for inserted in response_data['inserted_objects']:
+                    response = requests.put(
+                        f"{base_url}/datasets/{inserted[1]}", 
+                        json={"Source": source}
+                    )
+                    if response.status_code == 200:
+                        click.echo("Dataset updated successfully")
+                        
+            elif response.status_code == 400:
+                click.echo(f"Error: {response.json()['error']}")
+            else:
+                click.echo(f"Failed to upload the file. Status code: {response.status_code}")
+
         if delete_rosbag:
             print("Removing rosbag file")
             subprocess.run(f"rm {rosbag_file_name}", shell=True)
